@@ -76,23 +76,18 @@ void Parser::release_underlying()
   {
     context_->_private = 0; //Not really necessary.
     
-    if( context_->myDoc != NULL )
-    {
-      xmlFreeDoc(context_->myDoc);
-    }
-
     xmlFreeParserCtxt(context_);
     context_ = 0;
   }
 }
 
-void Parser::on_validity_error(const std::string& message)
+void Parser::on_validity_error(const Glib::ustring& message)
 {
   //Throw an exception later when the whole message has been received:
   validate_error_ += message;
 }
 
-void Parser::on_validity_warning(const std::string& message)
+void Parser::on_validity_warning(const Glib::ustring& message)
 {
   //Throw an exception later when the whole message has been received:
   validate_warning_ += message;
@@ -137,7 +132,7 @@ void Parser::callback_validity_error(void* context_, const char* msg, ...)
 
       try
       {
-        parser->on_validity_error(std::string(buff));
+        parser->on_validity_error(Glib::ustring(buff));
       }
       catch(const exception& e)
       {
@@ -168,7 +163,7 @@ void Parser::callback_validity_warning(void* context_, const char* msg, ...)
 
       try
       {
-        parser->on_validity_warning(std::string(buff));
+        parser->on_validity_warning(Glib::ustring(buff));
       }
       catch(const exception& e)
       {
@@ -194,7 +189,7 @@ void Parser::check_for_exception()
   
   if(exception_)
   {
-	  std::auto_ptr<exception> tmp ( exception_ );
+    exception* tmp = exception_;
     exception_ = 0;
     tmp->Raise();
   }
